==> haskell-mustache-2.4.3.1-61-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mustache
version:              2.4.3.1
visibility:           public
id:                   mustache-2.4.3.1-9Z1M73OaL6tE0eJhH2VphD
key:                  mustache-2.4.3.1-9Z1M73OaL6tE0eJhH2VphD
license:              BSD-3-Clause
copyright:            (c) 2015 - 2022 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache#readme
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  24e22fc39543f0e3df2aa3a59036e186
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:       Text.Mustache.Internal Text.Mustache.Internal.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mustache-2.4.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mustache-2.4.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mustache-2.4.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mustache
hs-libraries:         HSmustache-2.4.3.1-9Z1M73OaL6tE0eJhH2VphD
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1 parsec-3.1.16.1
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.6-IRGSsrKtWq3BZSHvMwfeE6
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mustache-2.4.3.1-62-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mustache
version:              2.4.3.1
visibility:           public
id:                   mustache-2.4.3.1-fK5yHeZZtM7dOSrI5Pxnb
key:                  mustache-2.4.3.1-fK5yHeZZtM7dOSrI5Pxnb
license:              BSD-3-Clause
copyright:            (c) 2015 - 2022 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache#readme
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  e8c99b199f0898c299f27e3aeaa0454b
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:       Text.Mustache.Internal Text.Mustache.Internal.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mustache-2.4.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mustache-2.4.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mustache-2.4.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mustache
hs-libraries:         HSmustache-2.4.3.1-fK5yHeZZtM7dOSrI5Pxnb
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1 parsec-3.1.16.1
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.6-IRGSsrKtWq3BZSHvMwfeE6
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
